# nodeum_sdk

Nodeum - the Ruby gem for the Nodeum API

The Nodeum API makes it easy to tap into the digital data mesh that runs across your organisation. Make requests to our API endpoints and we’ll give you everything you need to interconnect your business workflows with your storage.

All production API requests are made to:

http://nodeumhostname/api/

The current production version of the API is v1. 

**REST**
The Nodeum API is a RESTful API. This means that the API is designed to allow you to get, create, update, & delete objects with the HTTP verbs GET, POST, PUT, PATCH, & DELETE.

**JSON**
The Nodeum API speaks exclusively in JSON. This means that you should always set the Content-Type header to application/json to ensure that your requests are properly accepted and processed by the API.

**Authentication**
All API calls require user-password authentication. 

**Cross-Origin Resource Sharing**
The Nodeum API supports CORS for communicating from Javascript for these endpoints. You will need to specify an Origin URI when creating your application to allow for CORS to be whitelisted for your domain. 

**Pagination**
Some endpoints such as File Listing return a potentially lengthy array of objects. In order to keep the response sizes manageable the API will take advantage of pagination. Pagination is a mechanism for returning a subset of the results for a request and allowing for subsequent requests to “page” through the rest of the results until the end is reached. Paginated endpoints follow a standard interface that accepts two query parameters, limit and offset, and return a payload that follows a standard form. These parameters names and their behavior are borrowed from SQL LIMIT and OFFSET keywords.

**Versioning**
The Nodeum API is constantly being worked on to add features, make improvements, and fix bugs. This means that you should expect changes to be introduced and documented. 

However, there are some changes or additions that are considered backwards-compatible and your applications should be flexible enough to handle them. These include:

- Adding new endpoints to the API
- Adding new attributes to the response of an existing endpoint
- Changing the order of attributes of responses (JSON by definition is an object of unordered key/value pairs)

**Filter parameters**
When browsing a list of items, multiple filter parameters may be applied.
Some operators can be added to the value as a prefix:
 - `=` value is equal. Default operator, may be omitted
 - `!=` value is different
 - `>` greater than
 - `>=` greater than or equal
 - `<` lower than
 - `>=` lower than or equal
 - `><` included in list, items should be separated by `|`
 - `!><` not included in list, items should be separated by `|`
 - `~` pattern matching, may include `%` (any characters) and `_` (one character)
 - `!~` pattern not matching, may include `%` (any characters) and `_` (one character)
 

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.1.0
- Package version: 1.88.0
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://www.nodeum.io/](https://www.nodeum.io/)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build nodeum_sdk.gemspec
```

Then either install the gem locally:

```shell
gem install ./nodeum_sdk-1.88.0.gem
```

(for development, run `gem install --dev ./nodeum_sdk-1.88.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'nodeum_sdk', '~> 1.88.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/nodeum-io/nodeum-sdk-ruby, then add the following in the Gemfile:

    gem 'nodeum_sdk', :git => 'https://github.com/nodeum-io/nodeum-sdk-ruby.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'nodeum_sdk'

# Setup authorization
Nodeum.configure do |config|
  # Configure HTTP basic authorization: BasicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'

  # Configure API key authorization: BearerAuth
  config.api_key['Authorization'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['Authorization'] = 'Bearer'
end

api_instance = Nodeum::CloudBucketsApi.new
opts = {
  limit: 56, # Integer | The number of items to display for pagination.
  offset: 56, # Integer | The number of items to skip for pagination.
  sort_by: ['sort_by_example'], # Array<String> | Sort results by attribute.  Can sort on multiple attributes, separated by `|`. Order direction can be suffixing the attribute by either `:asc` (default) or `:desc`.
  id: 'id_example', # String | Filter on id
  cloud_connector_id: 'cloud_connector_id_example', # String | Filter on cloud connector id
  pool_id: 'pool_id_example', # String | Filter on a pool id
  name: 'name_example', # String | Filter on name
  location: 'location_example', # String | Filter on location
  price: 'price_example' # String | Filter on price
}

begin
  #Lists all cloud buckets.
  result = api_instance.index_cloud_buckets(opts)
  p result
rescue Nodeum::ApiError => e
  puts "Exception when calling CloudBucketsApi->index_cloud_buckets: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/api/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Nodeum::CloudBucketsApi* | [**index_cloud_buckets**](docs/CloudBucketsApi.md#index_cloud_buckets) | **GET** /cloud_buckets | Lists all cloud buckets.
*Nodeum::CloudBucketsApi* | [**index_cloud_buckets_by_cloud_connector**](docs/CloudBucketsApi.md#index_cloud_buckets_by_cloud_connector) | **GET** /cloud_connectors/{cloud_connector_id}/cloud_buckets | Lists all cloud buckets.
*Nodeum::CloudBucketsApi* | [**index_cloud_buckets_by_pool**](docs/CloudBucketsApi.md#index_cloud_buckets_by_pool) | **GET** /pools/{pool_id}/cloud_buckets | Lists all cloud buckets from pool.
*Nodeum::CloudBucketsApi* | [**mount_status_cloud_bucket**](docs/CloudBucketsApi.md#mount_status_cloud_bucket) | **GET** /cloud_buckets/{cloud_bucket_id}/mount | Get mount status of Cloud bucket.
*Nodeum::CloudBucketsApi* | [**mount_status_cloud_bucket_by_cloud_connector**](docs/CloudBucketsApi.md#mount_status_cloud_bucket_by_cloud_connector) | **GET** /cloud_connectors/{cloud_connector_id}/cloud_buckets/{cloud_bucket_id}/mount | Get mount status of Cloud bucket.
*Nodeum::CloudBucketsApi* | [**mount_status_cloud_bucket_by_pool**](docs/CloudBucketsApi.md#mount_status_cloud_bucket_by_pool) | **GET** /pools/{pool_id}/cloud_buckets/{cloud_bucket_id}/mount | Get mount status of Cloud bucket.
*Nodeum::CloudBucketsApi* | [**show_cloud_bucket**](docs/CloudBucketsApi.md#show_cloud_bucket) | **GET** /cloud_buckets/{cloud_bucket_id} | Displays a specific cloud bucket.
*Nodeum::CloudBucketsApi* | [**show_cloud_bucket_by_cloud_connector**](docs/CloudBucketsApi.md#show_cloud_bucket_by_cloud_connector) | **GET** /cloud_connectors/{cloud_connector_id}/cloud_buckets/{cloud_bucket_id} | Displays a specific cloud bucket.
*Nodeum::CloudBucketsApi* | [**show_cloud_bucket_by_pool**](docs/CloudBucketsApi.md#show_cloud_bucket_by_pool) | **GET** /pools/{pool_id}/cloud_buckets/{cloud_bucket_id} | Displays a specific cloud bucket.
*Nodeum::CloudBucketsApi* | [**sync_cloud_buckets**](docs/CloudBucketsApi.md#sync_cloud_buckets) | **PUT** /cloud_connectors/{cloud_connector_id}/cloud_buckets/-/sync | Synchronize internal cloud buckets with their remote equivalent.
*Nodeum::CloudBucketsApi* | [**sync_result_cloud_buckets**](docs/CloudBucketsApi.md#sync_result_cloud_buckets) | **GET** /cloud_connectors/{cloud_connector_id}/cloud_buckets/-/sync | Check result of cloud connector sync job.
*Nodeum::CloudBucketsApi* | [**update_cloud_bucket**](docs/CloudBucketsApi.md#update_cloud_bucket) | **PUT** /cloud_buckets/{cloud_bucket_id} | Updates a specific cloud bucket.
*Nodeum::CloudBucketsApi* | [**update_cloud_bucket_by_cloud_connector**](docs/CloudBucketsApi.md#update_cloud_bucket_by_cloud_connector) | **PUT** /cloud_connectors/{cloud_connector_id}/cloud_buckets/{cloud_bucket_id} | Updates a specific cloud bucket.
*Nodeum::CloudBucketsApi* | [**update_cloud_bucket_by_pool**](docs/CloudBucketsApi.md#update_cloud_bucket_by_pool) | **PUT** /pools/{pool_id}/cloud_buckets/{cloud_bucket_id} | Updates a specific cloud bucket.
*Nodeum::CloudBucketsApi* | [**update_config_file_cloud_bucket**](docs/CloudBucketsApi.md#update_config_file_cloud_bucket) | **PUT** /cloud_buckets/{cloud_bucket_id}/config_file | Updates a specific cloud bucket.
*Nodeum::CloudConnectorsApi* | [**create_cloud_connector**](docs/CloudConnectorsApi.md#create_cloud_connector) | **POST** /cloud_connectors | Creates a new cloud connector.
*Nodeum::CloudConnectorsApi* | [**destroy_cloud_connector**](docs/CloudConnectorsApi.md#destroy_cloud_connector) | **DELETE** /cloud_connectors/{cloud_connector_id} | Destroys a specific cloud connector.
*Nodeum::CloudConnectorsApi* | [**index_cloud_connectors**](docs/CloudConnectorsApi.md#index_cloud_connectors) | **GET** /cloud_connectors | Lists all cloud connectors.
*Nodeum::CloudConnectorsApi* | [**show_cloud_connector**](docs/CloudConnectorsApi.md#show_cloud_connector) | **GET** /cloud_connectors/{cloud_connector_id} | Displays a specific cloud connector.
*Nodeum::CloudConnectorsApi* | [**test_cloud_connector**](docs/CloudConnectorsApi.md#test_cloud_connector) | **PUT** /cloud_connectors/-/test | Test an unsaved cloud connector.
*Nodeum::CloudConnectorsApi* | [**test_result_cloud_connector**](docs/CloudConnectorsApi.md#test_result_cloud_connector) | **GET** /cloud_connectors/-/test | Check result of cloud connector test job.
*Nodeum::CloudConnectorsApi* | [**update_cloud_connector**](docs/CloudConnectorsApi.md#update_cloud_connector) | **PUT** /cloud_connectors/{cloud_connector_id} | Updates a specific cloud connector.
*Nodeum::ContainersApi* | [**create_container**](docs/ContainersApi.md#create_container) | **POST** /containers | Creates a new container.
*Nodeum::ContainersApi* | [**create_container_privilege**](docs/ContainersApi.md#create_container_privilege) | **POST** /containers/{container_id}/container_privileges | Creates a new privilege on the container.
*Nodeum::ContainersApi* | [**destroy_container**](docs/ContainersApi.md#destroy_container) | **DELETE** /containers/{container_id} | Destroys a specific container.
*Nodeum::ContainersApi* | [**destroy_container_privilege**](docs/ContainersApi.md#destroy_container_privilege) | **DELETE** /containers/{container_id}/container_privileges/{container_privilege_id} | Destroys a specific privilege.
*Nodeum::ContainersApi* | [**index_container_privileges**](docs/ContainersApi.md#index_container_privileges) | **GET** /containers/{container_id}/container_privileges | Lists all privilege on the container.
*Nodeum::ContainersApi* | [**index_containers**](docs/ContainersApi.md#index_containers) | **GET** /containers | Lists all containers.
*Nodeum::ContainersApi* | [**show_container**](docs/ContainersApi.md#show_container) | **GET** /containers/{container_id} | Displays a specific container.
*Nodeum::ContainersApi* | [**show_container_privilege**](docs/ContainersApi.md#show_container_privilege) | **GET** /containers/{container_id}/container_privileges/{container_privilege_id} | Displays a specific privilege.
*Nodeum::ContainersApi* | [**update_container**](docs/ContainersApi.md#update_container) | **PUT** /containers/{container_id} | Updates a specific container.
*Nodeum::ContainersApi* | [**update_container_privilege**](docs/ContainersApi.md#update_container_privilege) | **PUT** /containers/{container_id}/container_privileges/{container_privilege_id} | Updates a specific privilege.
*Nodeum::FilesApi* | [**files_children**](docs/FilesApi.md#files_children) | **GET** /files/{file_parent_id}/children | Lists files under a specific folder.
*Nodeum::FilesApi* | [**files_children_by_container**](docs/FilesApi.md#files_children_by_container) | **GET** /containers/{container_id}/files/{file_parent_id}/children | Lists files under a specific folder.
*Nodeum::FilesApi* | [**files_children_by_pool**](docs/FilesApi.md#files_children_by_pool) | **GET** /pools/{pool_id}/files/{file_parent_id}/children | Lists files under a specific folder.
*Nodeum::FilesApi* | [**files_children_by_task**](docs/FilesApi.md#files_children_by_task) | **GET** /tasks/{task_id}/files/{file_parent_id}/children | Lists files under a specific folder.
*Nodeum::FilesApi* | [**files_children_by_task_execution**](docs/FilesApi.md#files_children_by_task_execution) | **GET** /task_executions/{task_execution_id}/files/{file_parent_id}/children | Lists files under a specific folder.
*Nodeum::FilesApi* | [**files_children_by_task_execution_by_task**](docs/FilesApi.md#files_children_by_task_execution_by_task) | **GET** /tasks/{task_id}/task_executions/{task_execution_id}/files/{file_parent_id}/children | Lists files under a specific folder.
*Nodeum::FilesApi* | [**import_files_children_by_pool**](docs/FilesApi.md#import_files_children_by_pool) | **GET** /pools/{pool_id}/import_files/{file_parent_id}/children | Lists files under a specific folder on tape of pools, specific for Data Exchange.
*Nodeum::FilesApi* | [**index_files**](docs/FilesApi.md#index_files) | **GET** /files | Lists files on root.
*Nodeum::FilesApi* | [**index_files_by_container**](docs/FilesApi.md#index_files_by_container) | **GET** /containers/{container_id}/files | Lists files on root.
*Nodeum::FilesApi* | [**index_files_by_pool**](docs/FilesApi.md#index_files_by_pool) | **GET** /pools/{pool_id}/files | Lists files on root.
*Nodeum::FilesApi* | [**index_files_by_task**](docs/FilesApi.md#index_files_by_task) | **GET** /tasks/{task_id}/files | Lists files on root.
*Nodeum::FilesApi* | [**index_files_by_task_execution**](docs/FilesApi.md#index_files_by_task_execution) | **GET** /task_executions/{task_execution_id}/files | Lists files on root.
*Nodeum::FilesApi* | [**index_files_by_task_execution_by_task**](docs/FilesApi.md#index_files_by_task_execution_by_task) | **GET** /tasks/{task_id}/task_executions/{task_execution_id}/files | Lists files on root.
*Nodeum::FilesApi* | [**index_import_files_by_pool**](docs/FilesApi.md#index_import_files_by_pool) | **GET** /pools/{pool_id}/import_files | Lists files on root of tape of pools, specific for Data Exchange.
*Nodeum::FilesApi* | [**index_on_tapes_files_by_pool**](docs/FilesApi.md#index_on_tapes_files_by_pool) | **GET** /pools/{pool_id}/on_tapes_files | Lists files on root of tape of pools, specific for Active and Offline.
*Nodeum::FilesApi* | [**index_tapes_by_file_by_pool**](docs/FilesApi.md#index_tapes_by_file_by_pool) | **GET** /pools/{pool_id}/files/{file_id}/tapes | Displays tapes containing specific file, related to the specific pool.
*Nodeum::FilesApi* | [**index_tapes_by_file_by_task**](docs/FilesApi.md#index_tapes_by_file_by_task) | **GET** /tasks/{task_id}/files/{file_id}/tapes | Displays tapes containing specific file, related to the specific task.
*Nodeum::FilesApi* | [**index_tapes_by_file_by_task_execution**](docs/FilesApi.md#index_tapes_by_file_by_task_execution) | **GET** /task_executions/{task_execution_id}/files/{file_id}/tapes | Displays tapes containing specific file, related to the specific task.
*Nodeum::FilesApi* | [**index_tapes_by_file_by_task_execution_by_task**](docs/FilesApi.md#index_tapes_by_file_by_task_execution_by_task) | **GET** /tasks/{task_id}/task_executions/{task_execution_id}/files/{file_id}/tapes | Displays tapes containing specific file, related to the specific task.
*Nodeum::FilesApi* | [**on_tapes_files_children_by_pool**](docs/FilesApi.md#on_tapes_files_children_by_pool) | **GET** /pools/{pool_id}/on_tapes_files/{file_parent_id}/children | Lists files under a specific folder on tape of pools, specific for Active and Offline.
*Nodeum::FilesApi* | [**show_file**](docs/FilesApi.md#show_file) | **GET** /files/{file_id} | Displays a specific file.
*Nodeum::FilesApi* | [**show_file_by_container**](docs/FilesApi.md#show_file_by_container) | **GET** /containers/{container_id}/files/{file_id} | Displays a specific file.
*Nodeum::FilesApi* | [**show_file_by_pool**](docs/FilesApi.md#show_file_by_pool) | **GET** /pools/{pool_id}/files/{file_id} | Displays a specific file.
*Nodeum::FilesApi* | [**show_file_by_task**](docs/FilesApi.md#show_file_by_task) | **GET** /tasks/{task_id}/files/{file_id} | Displays a specific file.
*Nodeum::FilesApi* | [**show_file_by_task_execution**](docs/FilesApi.md#show_file_by_task_execution) | **GET** /task_executions/{task_execution_id}/files/{file_id} | Displays a specific file.
*Nodeum::FilesApi* | [**show_file_by_task_execution_by_task**](docs/FilesApi.md#show_file_by_task_execution_by_task) | **GET** /tasks/{task_id}/task_executions/{task_execution_id}/files/{file_id} | Displays a specific file.
*Nodeum::FilesApi* | [**show_import_file_by_pool**](docs/FilesApi.md#show_import_file_by_pool) | **GET** /pools/{pool_id}/import_files/{file_id} | Displays a specific file on tape of pools, specific for Data Exchange.
*Nodeum::FilesApi* | [**show_on_tape_file_by_pool**](docs/FilesApi.md#show_on_tape_file_by_pool) | **GET** /pools/{pool_id}/on_tapes_files/{file_id} | Displays a specific file on tape of pools, specific for Active and Offline.
*Nodeum::MetadataApi* | [**index_file_metadata_definitions**](docs/MetadataApi.md#index_file_metadata_definitions) | **GET** /file_metadata_definitions | List file metadata definitions
*Nodeum::MetadataApi* | [**index_task_metadata_definitions**](docs/MetadataApi.md#index_task_metadata_definitions) | **GET** /task_metadata_definitions | List task metadata definitions
*Nodeum::MetadataApi* | [**show_file_metadata_definition**](docs/MetadataApi.md#show_file_metadata_definition) | **GET** /file_metadata_definitions/{metadata_definition_id} | Displays a specific task metadata definition.
*Nodeum::MetadataApi* | [**show_task_metadata_definition**](docs/MetadataApi.md#show_task_metadata_definition) | **GET** /task_metadata_definitions/{metadata_definition_id} | Displays a specific task metadata definition.
*Nodeum::MountsApi* | [**index_mounts**](docs/MountsApi.md#index_mounts) | **GET** /mounts | List all mounted storages.
*Nodeum::NasApi* | [**create_nas**](docs/NasApi.md#create_nas) | **POST** /nas | Creates a new NAS.
*Nodeum::NasApi* | [**destroy_nas**](docs/NasApi.md#destroy_nas) | **DELETE** /nas/{nas_id} | Destroys a specific NAS.
*Nodeum::NasApi* | [**index_nas**](docs/NasApi.md#index_nas) | **GET** /nas | Lists all NAS.
*Nodeum::NasApi* | [**show_nas**](docs/NasApi.md#show_nas) | **GET** /nas/{nas_id} | Displays a specific NAS.
*Nodeum::NasApi* | [**update_nas**](docs/NasApi.md#update_nas) | **PUT** /nas/{nas_id} | Updates a specific NAS.
*Nodeum::NasSharesApi* | [**create_nas_share_by_nas**](docs/NasSharesApi.md#create_nas_share_by_nas) | **POST** /nas/{nas_id}/nas_shares | Creates a new NAS share.
*Nodeum::NasSharesApi* | [**destroy_nas_share**](docs/NasSharesApi.md#destroy_nas_share) | **DELETE** /nas_shares/{nas_share_id} | Destroys a specific NAS share.
*Nodeum::NasSharesApi* | [**destroy_nas_share_by_nas**](docs/NasSharesApi.md#destroy_nas_share_by_nas) | **DELETE** /nas/{nas_id}/nas_shares/{nas_share_id} | Destroys a specific NAS share.
*Nodeum::NasSharesApi* | [**destroy_nas_share_by_pool**](docs/NasSharesApi.md#destroy_nas_share_by_pool) | **DELETE** /pools/{pool_id}/nas_shares/{nas_share_id} | Destroys a specific NAS share.
*Nodeum::NasSharesApi* | [**index_nas_shares**](docs/NasSharesApi.md#index_nas_shares) | **GET** /nas_shares | Lists all NAS shares.
*Nodeum::NasSharesApi* | [**index_nas_shares_by_nas**](docs/NasSharesApi.md#index_nas_shares_by_nas) | **GET** /nas/{nas_id}/nas_shares | Lists all NAS shares.
*Nodeum::NasSharesApi* | [**index_nas_shares_by_pool**](docs/NasSharesApi.md#index_nas_shares_by_pool) | **GET** /pools/{pool_id}/nas_shares | Lists all NAS shares from pool.
*Nodeum::NasSharesApi* | [**mount_status_nas_share**](docs/NasSharesApi.md#mount_status_nas_share) | **GET** /nas_shares/{nas_share_id}/mount | Get mount status of NAS Share.
*Nodeum::NasSharesApi* | [**mount_status_nas_share_by_nas**](docs/NasSharesApi.md#mount_status_nas_share_by_nas) | **GET** /nas/{nas_id}/nas_shares/{nas_share_id}/mount | Get mount status of NAS Share.
*Nodeum::NasSharesApi* | [**mount_status_nas_share_by_pool**](docs/NasSharesApi.md#mount_status_nas_share_by_pool) | **GET** /pools/{pool_id}/nas_shares/{nas_share_id}/mount | Get mount status of NAS Share.
*Nodeum::NasSharesApi* | [**show_nas_share**](docs/NasSharesApi.md#show_nas_share) | **GET** /nas_shares/{nas_share_id} | Displays a specific NAS share.
*Nodeum::NasSharesApi* | [**show_nas_share_by_nas**](docs/NasSharesApi.md#show_nas_share_by_nas) | **GET** /nas/{nas_id}/nas_shares/{nas_share_id} | Displays a specific NAS share.
*Nodeum::NasSharesApi* | [**show_nas_share_by_pool**](docs/NasSharesApi.md#show_nas_share_by_pool) | **GET** /pools/{pool_id}/nas_shares/{nas_share_id} | Displays a specific NAS share.
*Nodeum::NasSharesApi* | [**test_nas_share**](docs/NasSharesApi.md#test_nas_share) | **PUT** /nas/{nas_id}/nas_shares/-/test | Test an unsaved NAS Share.
*Nodeum::NasSharesApi* | [**test_result_nas_share**](docs/NasSharesApi.md#test_result_nas_share) | **GET** /nas/{nas_id}/nas_shares/-/test | Check result of a NAS Share test job.
*Nodeum::NasSharesApi* | [**update_nas_share**](docs/NasSharesApi.md#update_nas_share) | **PUT** /nas_shares/{nas_share_id} | Updates a specific NAS share.
*Nodeum::NasSharesApi* | [**update_nas_share_by_nas**](docs/NasSharesApi.md#update_nas_share_by_nas) | **PUT** /nas/{nas_id}/nas_shares/{nas_share_id} | Updates a specific NAS share.
*Nodeum::NasSharesApi* | [**update_nas_share_by_pool**](docs/NasSharesApi.md#update_nas_share_by_pool) | **PUT** /pools/{pool_id}/nas_shares/{nas_share_id} | Updates a specific NAS share.
*Nodeum::PoolsApi* | [**create_pool**](docs/PoolsApi.md#create_pool) | **POST** /pools | Creates a new pool.
*Nodeum::PoolsApi* | [**create_primary_scan**](docs/PoolsApi.md#create_primary_scan) | **POST** /pools/{pool_id}/primary_scan | Set a new primary pool scan option.
*Nodeum::PoolsApi* | [**destroy_pool**](docs/PoolsApi.md#destroy_pool) | **DELETE** /pools/{pool_id} | Destroys a specific tape pool.
*Nodeum::PoolsApi* | [**destroy_primary_scan**](docs/PoolsApi.md#destroy_primary_scan) | **DELETE** /pools/{pool_id}/primary_scan | Disable the primary pool scan.
*Nodeum::PoolsApi* | [**index_pools**](docs/PoolsApi.md#index_pools) | **GET** /pools | Lists all pools.
*Nodeum::PoolsApi* | [**mount_pool**](docs/PoolsApi.md#mount_pool) | **PUT** /pools/{pool_id}/mount | Mount Pool.
*Nodeum::PoolsApi* | [**mount_status_pool**](docs/PoolsApi.md#mount_status_pool) | **GET** /pools/{pool_id}/mount | Get mount status of Pool.
*Nodeum::PoolsApi* | [**show_pool**](docs/PoolsApi.md#show_pool) | **GET** /pools/{pool_id} | Displays a specific pool.
*Nodeum::PoolsApi* | [**show_primary_scan**](docs/PoolsApi.md#show_primary_scan) | **GET** /pools/{pool_id}/primary_scan | Displays the primary pool scan status.
*Nodeum::PoolsApi* | [**sync_primary_pool**](docs/PoolsApi.md#sync_primary_pool) | **POST** /pools/{pool_id}/sync | Synchronize a primary after a scan (for internal use only).
*Nodeum::PoolsApi* | [**unmount_pool**](docs/PoolsApi.md#unmount_pool) | **DELETE** /pools/{pool_id}/mount | Unmount Pool.
*Nodeum::PoolsApi* | [**update_pool**](docs/PoolsApi.md#update_pool) | **PUT** /pools/{pool_id} | Updates a specific pool.
*Nodeum::PoolsApi* | [**update_primary_scan**](docs/PoolsApi.md#update_primary_scan) | **PUT** /pools/{pool_id}/primary_scan | Updates the existing primary pool scan option.
*Nodeum::StatisticsApi* | [**statistics_by_date**](docs/StatisticsApi.md#statistics_by_date) | **GET** /statistics/by_date | Get statistics about files, grouped by date
*Nodeum::StatisticsApi* | [**statistics_by_file_extension**](docs/StatisticsApi.md#statistics_by_file_extension) | **GET** /statistics/by_file_extension | Get statistics about files, grouped by file extension
*Nodeum::StatisticsApi* | [**statistics_by_group_owner**](docs/StatisticsApi.md#statistics_by_group_owner) | **GET** /statistics/by_group_owner | Get statistics about files, grouped by owner (group)
*Nodeum::StatisticsApi* | [**statistics_by_metadata**](docs/StatisticsApi.md#statistics_by_metadata) | **GET** /statistics/by_metadata | Get statistics about files, grouped by metadata
*Nodeum::StatisticsApi* | [**statistics_by_primary_cloud**](docs/StatisticsApi.md#statistics_by_primary_cloud) | **GET** /statistics/by_primary_cloud | Get statistics about files, grouped by primary Cloud
*Nodeum::StatisticsApi* | [**statistics_by_primary_name**](docs/StatisticsApi.md#statistics_by_primary_name) | **GET** /statistics/by_primary_name | Get statistics about files, grouped by primary storages
*Nodeum::StatisticsApi* | [**statistics_by_primary_nas**](docs/StatisticsApi.md#statistics_by_primary_nas) | **GET** /statistics/by_primary_nas | Get statistics about files, grouped by primary NAS
*Nodeum::StatisticsApi* | [**statistics_by_primary_storage**](docs/StatisticsApi.md#statistics_by_primary_storage) | **GET** /statistics/by_primary_storage | Get statistics about files, grouped by primary storage
*Nodeum::StatisticsApi* | [**statistics_by_secondary_cloud**](docs/StatisticsApi.md#statistics_by_secondary_cloud) | **GET** /statistics/by_secondary_cloud | Get statistics about files, grouped by secondary Cloud
*Nodeum::StatisticsApi* | [**statistics_by_secondary_nas**](docs/StatisticsApi.md#statistics_by_secondary_nas) | **GET** /statistics/by_secondary_nas | Get statistics about files, grouped by secondary NAS
*Nodeum::StatisticsApi* | [**statistics_by_secondary_storage**](docs/StatisticsApi.md#statistics_by_secondary_storage) | **GET** /statistics/by_secondary_storage | Get statistics about files, grouped by secondary storage
*Nodeum::StatisticsApi* | [**statistics_by_secondary_tape**](docs/StatisticsApi.md#statistics_by_secondary_tape) | **GET** /statistics/by_secondary_tape | Get statistics about files, grouped by secondary Tape
*Nodeum::StatisticsApi* | [**statistics_by_size**](docs/StatisticsApi.md#statistics_by_size) | **GET** /statistics/by_size | Get statistics about files, grouped by size
*Nodeum::StatisticsApi* | [**statistics_by_user_owner**](docs/StatisticsApi.md#statistics_by_user_owner) | **GET** /statistics/by_user_owner | Get statistics about files, grouped by owner (user)
*Nodeum::StatisticsApi* | [**statistics_storage**](docs/StatisticsApi.md#statistics_storage) | **GET** /statistics/storage | Get statistics about storages, grouped by types
*Nodeum::StatisticsApi* | [**statistics_task_by_metadata**](docs/StatisticsApi.md#statistics_task_by_metadata) | **GET** /statistics/task_by_metadata | Get statistics about tasks executions, grouped by metadata
*Nodeum::StatisticsApi* | [**statistics_task_by_status**](docs/StatisticsApi.md#statistics_task_by_status) | **GET** /statistics/task_by_status | Get statistics about tasks executions, grouped by status
*Nodeum::StatisticsApi* | [**statistics_task_by_storage**](docs/StatisticsApi.md#statistics_task_by_storage) | **GET** /statistics/task_by_storage | Get statistics about tasks executions, grouped by source and destination
*Nodeum::StatisticsApi* | [**statistics_task_by_workflow**](docs/StatisticsApi.md#statistics_task_by_workflow) | **GET** /statistics/task_by_workflow | Get statistics about tasks executions, grouped by workflow
*Nodeum::SystemsApi* | [**download_reset_vars**](docs/SystemsApi.md#download_reset_vars) | **POST** /systems/reset/generate_vars | Creates a YAML file with selected tables and downloads it
*Nodeum::SystemsApi* | [**result_download_traces**](docs/SystemsApi.md#result_download_traces) | **GET** /systems/download_traces | Check result of a download traces job.
*Nodeum::SystemsApi* | [**trigger_download_traces**](docs/SystemsApi.md#trigger_download_traces) | **PUT** /systems/download_traces | Trigger a download traces request.
*Nodeum::TapeDrivesApi* | [**create_tape_drive_by_tape_library**](docs/TapeDrivesApi.md#create_tape_drive_by_tape_library) | **POST** /tape_libraries/{tape_library_id}/tape_drives | Creates a new tape drive.
*Nodeum::TapeDrivesApi* | [**destroy_tape_drive**](docs/TapeDrivesApi.md#destroy_tape_drive) | **DELETE** /tape_drives/{tape_drive_id} | Destroys a specific tape drive.
*Nodeum::TapeDrivesApi* | [**destroy_tape_drive_by_tape_library**](docs/TapeDrivesApi.md#destroy_tape_drive_by_tape_library) | **DELETE** /tape_libraries/{tape_library_id}/tape_drives/{tape_drive_id} | Destroys a specific tape drive.
*Nodeum::TapeDrivesApi* | [**index_tape_drive_devices**](docs/TapeDrivesApi.md#index_tape_drive_devices) | **GET** /tape_libraries/{tape_library_id}/tape_drives/-/devices | Lists tape drives devices.
*Nodeum::TapeDrivesApi* | [**index_tape_drives**](docs/TapeDrivesApi.md#index_tape_drives) | **GET** /tape_drives | Lists all tape drives.
*Nodeum::TapeDrivesApi* | [**index_tape_drives_by_tape_library**](docs/TapeDrivesApi.md#index_tape_drives_by_tape_library) | **GET** /tape_libraries/{tape_library_id}/tape_drives | Lists all tape drives.
*Nodeum::TapeDrivesApi* | [**show_tape_drive**](docs/TapeDrivesApi.md#show_tape_drive) | **GET** /tape_drives/{tape_drive_id} | Displays a specific tape drive.
*Nodeum::TapeDrivesApi* | [**show_tape_drive_by_tape_library**](docs/TapeDrivesApi.md#show_tape_drive_by_tape_library) | **GET** /tape_libraries/{tape_library_id}/tape_drives/{tape_drive_id} | Displays a specific tape drive.
*Nodeum::TapeDrivesApi* | [**update_tape_drive**](docs/TapeDrivesApi.md#update_tape_drive) | **PUT** /tape_drives/{tape_drive_id} | Updates a specific tape drive.
*Nodeum::TapeDrivesApi* | [**update_tape_drive_by_tape_library**](docs/TapeDrivesApi.md#update_tape_drive_by_tape_library) | **PUT** /tape_libraries/{tape_library_id}/tape_drives/{tape_drive_id} | Updates a specific tape drive.
*Nodeum::TapeLibrariesApi* | [**create_tape_library**](docs/TapeLibrariesApi.md#create_tape_library) | **POST** /tape_libraries | Creates a new tape library.
*Nodeum::TapeLibrariesApi* | [**destroy_tape_library**](docs/TapeLibrariesApi.md#destroy_tape_library) | **DELETE** /tape_libraries/{tape_library_id} | Destroys a specific tape library.
*Nodeum::TapeLibrariesApi* | [**index_tape_libraries**](docs/TapeLibrariesApi.md#index_tape_libraries) | **GET** /tape_libraries | Lists all tape libraries.
*Nodeum::TapeLibrariesApi* | [**index_tape_library_devices**](docs/TapeLibrariesApi.md#index_tape_library_devices) | **GET** /tape_libraries/-/devices | Lists tape libraries devices.
*Nodeum::TapeLibrariesApi* | [**show_tape_library**](docs/TapeLibrariesApi.md#show_tape_library) | **GET** /tape_libraries/{tape_library_id} | Displays a specific tape library.
*Nodeum::TapeLibrariesApi* | [**update_tape_library**](docs/TapeLibrariesApi.md#update_tape_library) | **PUT** /tape_libraries/{tape_library_id} | Updates a specific tape library.
*Nodeum::TapesApi* | [**destroy_tape**](docs/TapesApi.md#destroy_tape) | **DELETE** /tapes/{tape_id} | Destroys a specific tape. Only when it's an orphan.
*Nodeum::TapesApi* | [**index_tape_stats**](docs/TapesApi.md#index_tape_stats) | **GET** /tape_stats | List all tape statistics.
*Nodeum::TapesApi* | [**index_tapes**](docs/TapesApi.md#index_tapes) | **GET** /tapes | Lists all tapes.
*Nodeum::TapesApi* | [**index_tapes_by_pool**](docs/TapesApi.md#index_tapes_by_pool) | **GET** /pools/{pool_id}/tapes | Lists all tapes.
*Nodeum::TapesApi* | [**index_tapes_by_tape_library**](docs/TapesApi.md#index_tapes_by_tape_library) | **GET** /tape_libraries/{tape_library_id}/tapes | Lists all tapes.
*Nodeum::TapesApi* | [**mount_status_tape**](docs/TapesApi.md#mount_status_tape) | **GET** /tapes/{tape_id}/mount | Get mount status of Tape.
*Nodeum::TapesApi* | [**mount_status_tape_by_pool**](docs/TapesApi.md#mount_status_tape_by_pool) | **GET** /pools/{pool_id}/tapes/{tape_id}/mount | Get mount status of Tape.
*Nodeum::TapesApi* | [**mount_status_tape_by_tape_library**](docs/TapesApi.md#mount_status_tape_by_tape_library) | **GET** /tape_libraries/{tape_library_id}/tapes/{tape_id}/mount | Get mount status of Tape.
*Nodeum::TapesApi* | [**show_tape**](docs/TapesApi.md#show_tape) | **GET** /tapes/{tape_id} | Displays a specific tape.
*Nodeum::TapesApi* | [**show_tape_by_pool**](docs/TapesApi.md#show_tape_by_pool) | **GET** /pools/{pool_id}/tapes/{tape_id} | Displays a specific tape.
*Nodeum::TapesApi* | [**show_tape_by_tape_library**](docs/TapesApi.md#show_tape_by_tape_library) | **GET** /tape_libraries/{tape_library_id}/tapes/{tape_id} | Displays a specific tape.
*Nodeum::TapesApi* | [**show_tape_stat**](docs/TapesApi.md#show_tape_stat) | **GET** /tapes/{tape_id}/tape_stat | Display statistic for a specific tape.
*Nodeum::TapesApi* | [**show_tape_stat_by_pool**](docs/TapesApi.md#show_tape_stat_by_pool) | **GET** /pools/{pool_id}/tapes/{tape_id}/tape_stat | Display statistic for a specific tape.
*Nodeum::TapesApi* | [**show_tape_stat_by_tape_library**](docs/TapesApi.md#show_tape_stat_by_tape_library) | **GET** /tape_libraries/{tape_library_id}/tapes/{tape_id}/tape_stat | Display statistic for a specific tape.
*Nodeum::TaskCallbacksApi* | [**create_task_callback**](docs/TaskCallbacksApi.md#create_task_callback) | **POST** /tasks/{task_id}/task_callbacks | Creates a new task callback.
*Nodeum::TaskCallbacksApi* | [**destroy_task_callback**](docs/TaskCallbacksApi.md#destroy_task_callback) | **DELETE** /tasks/{task_id}/task_callbacks/{task_callback_id} | Destroys a specific task callback.
*Nodeum::TaskCallbacksApi* | [**index_task_callbacks**](docs/TaskCallbacksApi.md#index_task_callbacks) | **GET** /tasks/{task_id}/task_callbacks | Lists all task callbacks.
*Nodeum::TaskCallbacksApi* | [**show_task_callback**](docs/TaskCallbacksApi.md#show_task_callback) | **GET** /tasks/{task_id}/task_callbacks/{task_callback_id} | Displays a specific task callback.
*Nodeum::TaskCallbacksApi* | [**update_task_callback**](docs/TaskCallbacksApi.md#update_task_callback) | **PUT** /tasks/{task_id}/task_callbacks/{task_callback_id} | Updates a specific task callback.
*Nodeum::TaskDestinationsApi* | [**create_task_destination**](docs/TaskDestinationsApi.md#create_task_destination) | **POST** /tasks/{task_id}/task_destinations | Creates a new task destination.
*Nodeum::TaskDestinationsApi* | [**destroy_task_destination**](docs/TaskDestinationsApi.md#destroy_task_destination) | **DELETE** /tasks/{task_id}/task_destinations/{task_destination_id} | Destroys a specific task destination.
*Nodeum::TaskDestinationsApi* | [**index_task_destinations**](docs/TaskDestinationsApi.md#index_task_destinations) | **GET** /tasks/{task_id}/task_destinations | Lists all task destinations.
*Nodeum::TaskDestinationsApi* | [**show_task_destination**](docs/TaskDestinationsApi.md#show_task_destination) | **GET** /tasks/{task_id}/task_destinations/{task_destination_id} | Displays a specific task destination.
*Nodeum::TaskDestinationsApi* | [**update_task_destination**](docs/TaskDestinationsApi.md#update_task_destination) | **PUT** /tasks/{task_id}/task_destinations/{task_destination_id} | Updates a specific task destination.
*Nodeum::TaskExecutionsApi* | [**index_task_executions**](docs/TaskExecutionsApi.md#index_task_executions) | **GET** /task_executions | Lists all task executions.
*Nodeum::TaskExecutionsApi* | [**index_task_executions_by_task**](docs/TaskExecutionsApi.md#index_task_executions_by_task) | **GET** /tasks/{task_id}/task_executions | Lists all task executions.
*Nodeum::TaskExecutionsApi* | [**show_task_execution**](docs/TaskExecutionsApi.md#show_task_execution) | **GET** /task_executions/{task_execution_id} | Displays a specific task execution.
*Nodeum::TaskExecutionsApi* | [**show_task_execution_by_task**](docs/TaskExecutionsApi.md#show_task_execution_by_task) | **GET** /tasks/{task_id}/task_executions/{task_execution_id} | Displays a specific task execution.
*Nodeum::TaskMetadataApi* | [**create_task_metadatum**](docs/TaskMetadataApi.md#create_task_metadatum) | **POST** /tasks/{task_id}/task_metadata | Creates a new task metadatum.
*Nodeum::TaskMetadataApi* | [**destroy_task_metadatum**](docs/TaskMetadataApi.md#destroy_task_metadatum) | **DELETE** /tasks/{task_id}/task_metadata/{task_metadatum_id} | Destroys a specific task metadatum.
*Nodeum::TaskMetadataApi* | [**index_task_metadata**](docs/TaskMetadataApi.md#index_task_metadata) | **GET** /tasks/{task_id}/task_metadata | Lists all task metadata.
*Nodeum::TaskMetadataApi* | [**show_task_metadatum**](docs/TaskMetadataApi.md#show_task_metadatum) | **GET** /tasks/{task_id}/task_metadata/{task_metadatum_id} | Displays a specific task metadatum.
*Nodeum::TaskMetadataApi* | [**update_task_metadatum**](docs/TaskMetadataApi.md#update_task_metadatum) | **PUT** /tasks/{task_id}/task_metadata/{task_metadatum_id} | Updates a specific task metadatum.
*Nodeum::TaskOptionsApi* | [**create_task_option**](docs/TaskOptionsApi.md#create_task_option) | **POST** /tasks/{task_id}/task_options | Creates a new task option.
*Nodeum::TaskOptionsApi* | [**destroy_task_option**](docs/TaskOptionsApi.md#destroy_task_option) | **DELETE** /tasks/{task_id}/task_options/{task_option_id} | Destroys a specific task option.
*Nodeum::TaskOptionsApi* | [**index_task_options**](docs/TaskOptionsApi.md#index_task_options) | **GET** /tasks/{task_id}/task_options | Lists all task options.
*Nodeum::TaskOptionsApi* | [**show_task_option**](docs/TaskOptionsApi.md#show_task_option) | **GET** /tasks/{task_id}/task_options/{task_option_id} | Displays a specific task option.
*Nodeum::TaskOptionsApi* | [**update_task_option**](docs/TaskOptionsApi.md#update_task_option) | **PUT** /tasks/{task_id}/task_options/{task_option_id} | Updates a specific task option.
*Nodeum::TaskSchedulesApi* | [**create_task_schedule**](docs/TaskSchedulesApi.md#create_task_schedule) | **POST** /tasks/{task_id}/task_schedule | Creates a new task schedule. Only one should be created.
*Nodeum::TaskSchedulesApi* | [**destroy_task_schedule**](docs/TaskSchedulesApi.md#destroy_task_schedule) | **DELETE** /tasks/{task_id}/task_schedule | Destroys the task schedule.
*Nodeum::TaskSchedulesApi* | [**index_task_schedules**](docs/TaskSchedulesApi.md#index_task_schedules) | **GET** /task_schedules | Lists all task schedules.
*Nodeum::TaskSchedulesApi* | [**show_task_schedule**](docs/TaskSchedulesApi.md#show_task_schedule) | **GET** /tasks/{task_id}/task_schedule | Displays the task schedule.
*Nodeum::TaskSchedulesApi* | [**update_task_schedule**](docs/TaskSchedulesApi.md#update_task_schedule) | **PUT** /tasks/{task_id}/task_schedule | Updates the existing task schedule.
*Nodeum::TaskSourcesApi* | [**create_task_source**](docs/TaskSourcesApi.md#create_task_source) | **POST** /tasks/{task_id}/task_sources | Creates a new task source.
*Nodeum::TaskSourcesApi* | [**destroy_task_source**](docs/TaskSourcesApi.md#destroy_task_source) | **DELETE** /tasks/{task_id}/task_sources/{task_source_id} | Destroys a specific task source.
*Nodeum::TaskSourcesApi* | [**index_task_sources**](docs/TaskSourcesApi.md#index_task_sources) | **GET** /tasks/{task_id}/task_sources | Lists all task sources.
*Nodeum::TaskSourcesApi* | [**show_task_source**](docs/TaskSourcesApi.md#show_task_source) | **GET** /tasks/{task_id}/task_sources/{task_source_id} | Displays a specific task source.
*Nodeum::TaskSourcesApi* | [**update_task_source**](docs/TaskSourcesApi.md#update_task_source) | **PUT** /tasks/{task_id}/task_sources/{task_source_id} | Updates a specific task source.
*Nodeum::TasksApi* | [**create_task**](docs/TasksApi.md#create_task) | **POST** /tasks | Creates a new task.
*Nodeum::TasksApi* | [**destroy_task**](docs/TasksApi.md#destroy_task) | **DELETE** /tasks/{task_id} | Destroys a specific task.
*Nodeum::TasksApi* | [**index_tasks**](docs/TasksApi.md#index_tasks) | **GET** /tasks | Lists all tasks.
*Nodeum::TasksApi* | [**pause_task**](docs/TasksApi.md#pause_task) | **PUT** /tasks/{task_id}/action/pause | Pause a task.
*Nodeum::TasksApi* | [**pause_task_result**](docs/TasksApi.md#pause_task_result) | **GET** /tasks/{task_id}/action/pause | Check result of a task pause request.
*Nodeum::TasksApi* | [**resume_task**](docs/TasksApi.md#resume_task) | **PUT** /tasks/{task_id}/action/resume | Resume a task.
*Nodeum::TasksApi* | [**resume_task_result**](docs/TasksApi.md#resume_task_result) | **GET** /tasks/{task_id}/action/resume | Check result of a task resume request.
*Nodeum::TasksApi* | [**run_task**](docs/TasksApi.md#run_task) | **PUT** /tasks/{task_id}/action/run | Run a task.
*Nodeum::TasksApi* | [**run_task_result**](docs/TasksApi.md#run_task_result) | **GET** /tasks/{task_id}/action/run | Check result of a task run request.
*Nodeum::TasksApi* | [**show_task**](docs/TasksApi.md#show_task) | **GET** /tasks/{task_id} | Displays a specific task.
*Nodeum::TasksApi* | [**stop_task**](docs/TasksApi.md#stop_task) | **PUT** /tasks/{task_id}/action/stop | Stop a task.
*Nodeum::TasksApi* | [**stop_task_result**](docs/TasksApi.md#stop_task_result) | **GET** /tasks/{task_id}/action/stop | Check result of a task stop request.
*Nodeum::TasksApi* | [**update_task**](docs/TasksApi.md#update_task) | **PUT** /tasks/{task_id} | Updates a specific task.
*Nodeum::UsersApi* | [**create_api_key**](docs/UsersApi.md#create_api_key) | **POST** /users/me/api_keys | Creates a new API Key for current user.
*Nodeum::UsersApi* | [**create_configuration**](docs/UsersApi.md#create_configuration) | **POST** /users/me/configurations | Creates a new configuration value for current user.
*Nodeum::UsersApi* | [**destroy_api_key**](docs/UsersApi.md#destroy_api_key) | **DELETE** /users/me/api_keys/{api_key_id} | Destroys a specific API Key.
*Nodeum::UsersApi* | [**destroy_configuration**](docs/UsersApi.md#destroy_configuration) | **DELETE** /users/me/configurations/{configuration_id} | Destroys a specific configuration value.
*Nodeum::UsersApi* | [**index_api_keys**](docs/UsersApi.md#index_api_keys) | **GET** /users/me/api_keys | Lists all API keys of current user.
*Nodeum::UsersApi* | [**index_configurations**](docs/UsersApi.md#index_configurations) | **GET** /users/me/configurations | Lists all configurations of current user.
*Nodeum::UsersApi* | [**index_system_groups**](docs/UsersApi.md#index_system_groups) | **GET** /groups/-/systems | List all system groups.
*Nodeum::UsersApi* | [**index_system_users**](docs/UsersApi.md#index_system_users) | **GET** /users/-/systems | List all system users.
*Nodeum::UsersApi* | [**show_api_key**](docs/UsersApi.md#show_api_key) | **GET** /users/me/api_keys/{api_key_id} | Displays a specific API Key with its scopes.
*Nodeum::UsersApi* | [**show_configuration**](docs/UsersApi.md#show_configuration) | **GET** /users/me/configurations/{configuration_id} | Displays a specific configuration value.
*Nodeum::UsersApi* | [**update_api_key**](docs/UsersApi.md#update_api_key) | **PUT** /users/me/api_keys/{api_key_id} | Updates a specific API Key.
*Nodeum::UsersApi* | [**update_configuration**](docs/UsersApi.md#update_configuration) | **PUT** /users/me/configurations/{configuration_id} | Updates a specific configuration value.


## Documentation for Models

 - [Nodeum::ActiveJobStatus](docs/ActiveJobStatus.md)
 - [Nodeum::ApiKey](docs/ApiKey.md)
 - [Nodeum::ApiKeyCollection](docs/ApiKeyCollection.md)
 - [Nodeum::ApiKeyFull](docs/ApiKeyFull.md)
 - [Nodeum::ApiKeyFullAllOf](docs/ApiKeyFullAllOf.md)
 - [Nodeum::ApiKeyScope](docs/ApiKeyScope.md)
 - [Nodeum::AttributeError](docs/AttributeError.md)
 - [Nodeum::Blank](docs/Blank.md)
 - [Nodeum::ByDateFacet](docs/ByDateFacet.md)
 - [Nodeum::ByDateFacetBucket](docs/ByDateFacetBucket.md)
 - [Nodeum::ByDateFacetBucketAllOf](docs/ByDateFacetBucketAllOf.md)
 - [Nodeum::ByDateFacetBuckets](docs/ByDateFacetBuckets.md)
 - [Nodeum::ByFileExtensionFacet](docs/ByFileExtensionFacet.md)
 - [Nodeum::ByFileExtensionFacetAllOf](docs/ByFileExtensionFacetAllOf.md)
 - [Nodeum::ByGroupOwnerFacet](docs/ByGroupOwnerFacet.md)
 - [Nodeum::ByGroupOwnerFacetAllOf](docs/ByGroupOwnerFacetAllOf.md)
 - [Nodeum::ByMetadataBucket](docs/ByMetadataBucket.md)
 - [Nodeum::ByMetadataBucketAllOf](docs/ByMetadataBucketAllOf.md)
 - [Nodeum::ByMetadataFacet](docs/ByMetadataFacet.md)
 - [Nodeum::ByMetadataFacetAllOf](docs/ByMetadataFacetAllOf.md)
 - [Nodeum::ByMetadataKeyBucket](docs/ByMetadataKeyBucket.md)
 - [Nodeum::ByMetadataKeyBucketAllOf](docs/ByMetadataKeyBucketAllOf.md)
 - [Nodeum::ByMetadataKeyBuckets](docs/ByMetadataKeyBuckets.md)
 - [Nodeum::ByMetadataValueBuckets](docs/ByMetadataValueBuckets.md)
 - [Nodeum::ByPrimaryCloudFacet](docs/ByPrimaryCloudFacet.md)
 - [Nodeum::ByPrimaryCloudFacetAllOf](docs/ByPrimaryCloudFacetAllOf.md)
 - [Nodeum::ByPrimaryFacet](docs/ByPrimaryFacet.md)
 - [Nodeum::ByPrimaryFacetAllOf](docs/ByPrimaryFacetAllOf.md)
 - [Nodeum::ByPrimaryNasFacet](docs/ByPrimaryNasFacet.md)
 - [Nodeum::ByPrimaryNasFacetAllOf](docs/ByPrimaryNasFacetAllOf.md)
 - [Nodeum::ByPrimaryStorageFacet](docs/ByPrimaryStorageFacet.md)
 - [Nodeum::ByPrimaryTypeFacet](docs/ByPrimaryTypeFacet.md)
 - [Nodeum::BySecondaryCloudFacet](docs/BySecondaryCloudFacet.md)
 - [Nodeum::BySecondaryCloudFacetAllOf](docs/BySecondaryCloudFacetAllOf.md)
 - [Nodeum::BySecondaryNasFacet](docs/BySecondaryNasFacet.md)
 - [Nodeum::BySecondaryNasFacetAllOf](docs/BySecondaryNasFacetAllOf.md)
 - [Nodeum::BySecondaryStorageFacet](docs/BySecondaryStorageFacet.md)
 - [Nodeum::BySecondaryTapeFacet](docs/BySecondaryTapeFacet.md)
 - [Nodeum::BySecondaryTapeFacetAllOf](docs/BySecondaryTapeFacetAllOf.md)
 - [Nodeum::BySecondaryTypeFacet](docs/BySecondaryTypeFacet.md)
 - [Nodeum::BySecondaryTypeFacetAllOf](docs/BySecondaryTypeFacetAllOf.md)
 - [Nodeum::BySizeFacet](docs/BySizeFacet.md)
 - [Nodeum::ByTaskMetadataFacet](docs/ByTaskMetadataFacet.md)
 - [Nodeum::ByTaskMetadataFacetAllOf](docs/ByTaskMetadataFacetAllOf.md)
 - [Nodeum::ByTaskStatusFacet](docs/ByTaskStatusFacet.md)
 - [Nodeum::ByTaskStatusFacetAllOf](docs/ByTaskStatusFacetAllOf.md)
 - [Nodeum::ByTaskStorageFacet](docs/ByTaskStorageFacet.md)
 - [Nodeum::ByTaskStorageFacetAllOf](docs/ByTaskStorageFacetAllOf.md)
 - [Nodeum::ByTaskWorkflowFacet](docs/ByTaskWorkflowFacet.md)
 - [Nodeum::ByTaskWorkflowFacetAllOf](docs/ByTaskWorkflowFacetAllOf.md)
 - [Nodeum::ByTypeFacetBucket](docs/ByTypeFacetBucket.md)
 - [Nodeum::ByTypeFacetBuckets](docs/ByTypeFacetBuckets.md)
 - [Nodeum::ByUserOwnerFacet](docs/ByUserOwnerFacet.md)
 - [Nodeum::ByUserOwnerFacetAllOf](docs/ByUserOwnerFacetAllOf.md)
 - [Nodeum::CloudBucket](docs/CloudBucket.md)
 - [Nodeum::CloudBucketCollection](docs/CloudBucketCollection.md)
 - [Nodeum::CloudBucketSimpleCollection](docs/CloudBucketSimpleCollection.md)
 - [Nodeum::CloudConnector](docs/CloudConnector.md)
 - [Nodeum::CloudConnectorCollection](docs/CloudConnectorCollection.md)
 - [Nodeum::Container](docs/Container.md)
 - [Nodeum::ContainerCollection](docs/ContainerCollection.md)
 - [Nodeum::ContainerPrivilege](docs/ContainerPrivilege.md)
 - [Nodeum::ContainerPrivilegeCollection](docs/ContainerPrivilegeCollection.md)
 - [Nodeum::DateToFileFacets](docs/DateToFileFacets.md)
 - [Nodeum::DefaultFacet](docs/DefaultFacet.md)
 - [Nodeum::Error](docs/Error.md)
 - [Nodeum::FileFacet](docs/FileFacet.md)
 - [Nodeum::FileFacetAllOf](docs/FileFacetAllOf.md)
 - [Nodeum::FileMetadataDefinition](docs/FileMetadataDefinition.md)
 - [Nodeum::FileMetadataDefinitionCollection](docs/FileMetadataDefinitionCollection.md)
 - [Nodeum::Frozen](docs/Frozen.md)
 - [Nodeum::GreaterThan](docs/GreaterThan.md)
 - [Nodeum::GreaterThanAllOf](docs/GreaterThanAllOf.md)
 - [Nodeum::GreaterThanOrEqualTo](docs/GreaterThanOrEqualTo.md)
 - [Nodeum::ImportFile](docs/ImportFile.md)
 - [Nodeum::ImportFileCollection](docs/ImportFileCollection.md)
 - [Nodeum::ImportFileWithPath](docs/ImportFileWithPath.md)
 - [Nodeum::Invalid](docs/Invalid.md)
 - [Nodeum::LessThan](docs/LessThan.md)
 - [Nodeum::LessThanAllOf](docs/LessThanAllOf.md)
 - [Nodeum::LessThanOrEqualTo](docs/LessThanOrEqualTo.md)
 - [Nodeum::MetadataDefinition](docs/MetadataDefinition.md)
 - [Nodeum::MountCollection](docs/MountCollection.md)
 - [Nodeum::MountInfo](docs/MountInfo.md)
 - [Nodeum::MountNotification](docs/MountNotification.md)
 - [Nodeum::MountStatus](docs/MountStatus.md)
 - [Nodeum::Nas](docs/Nas.md)
 - [Nodeum::NasCollection](docs/NasCollection.md)
 - [Nodeum::NasShare](docs/NasShare.md)
 - [Nodeum::NasShareCollection](docs/NasShareCollection.md)
 - [Nodeum::NodeumFile](docs/NodeumFile.md)
 - [Nodeum::NodeumFileCollection](docs/NodeumFileCollection.md)
 - [Nodeum::NodeumFileWithPath](docs/NodeumFileWithPath.md)
 - [Nodeum::NodeumFileWithPathAllOf](docs/NodeumFileWithPathAllOf.md)
 - [Nodeum::OccurrenceLessThan](docs/OccurrenceLessThan.md)
 - [Nodeum::OccurrenceLessThanAllOf](docs/OccurrenceLessThanAllOf.md)
 - [Nodeum::OccurrenceLessThanOrEqualTo](docs/OccurrenceLessThanOrEqualTo.md)
 - [Nodeum::OnTapesFile](docs/OnTapesFile.md)
 - [Nodeum::OnTapesFileCollection](docs/OnTapesFileCollection.md)
 - [Nodeum::Pool](docs/Pool.md)
 - [Nodeum::PoolCollection](docs/PoolCollection.md)
 - [Nodeum::PoolUp](docs/PoolUp.md)
 - [Nodeum::PoolUpAllOf](docs/PoolUpAllOf.md)
 - [Nodeum::PrimaryScan](docs/PrimaryScan.md)
 - [Nodeum::QuotaOnCache](docs/QuotaOnCache.md)
 - [Nodeum::Reset](docs/Reset.md)
 - [Nodeum::ResetSections](docs/ResetSections.md)
 - [Nodeum::SizeToDateFacets](docs/SizeToDateFacets.md)
 - [Nodeum::StorageByTypeFacets](docs/StorageByTypeFacets.md)
 - [Nodeum::StorageCloudBucketByTypeFacets](docs/StorageCloudBucketByTypeFacets.md)
 - [Nodeum::StorageCloudBucketFacets](docs/StorageCloudBucketFacets.md)
 - [Nodeum::StorageFacet](docs/StorageFacet.md)
 - [Nodeum::StorageNasShareByTypeFacets](docs/StorageNasShareByTypeFacets.md)
 - [Nodeum::StorageNasShareFacets](docs/StorageNasShareFacets.md)
 - [Nodeum::StoragePoolByTypeFacets](docs/StoragePoolByTypeFacets.md)
 - [Nodeum::StoragePoolFacets](docs/StoragePoolFacets.md)
 - [Nodeum::StorageTapeByTypeFacets](docs/StorageTapeByTypeFacets.md)
 - [Nodeum::StorageTapeFacets](docs/StorageTapeFacets.md)
 - [Nodeum::SystemGroup](docs/SystemGroup.md)
 - [Nodeum::SystemGroupCollection](docs/SystemGroupCollection.md)
 - [Nodeum::SystemUser](docs/SystemUser.md)
 - [Nodeum::SystemUserCollection](docs/SystemUserCollection.md)
 - [Nodeum::Taken](docs/Taken.md)
 - [Nodeum::TakenAllOf](docs/TakenAllOf.md)
 - [Nodeum::Tape](docs/Tape.md)
 - [Nodeum::TapeCollection](docs/TapeCollection.md)
 - [Nodeum::TapeDrive](docs/TapeDrive.md)
 - [Nodeum::TapeDriveAllOf](docs/TapeDriveAllOf.md)
 - [Nodeum::TapeDriveCollection](docs/TapeDriveCollection.md)
 - [Nodeum::TapeDriveDevice](docs/TapeDriveDevice.md)
 - [Nodeum::TapeDriveDeviceCollection](docs/TapeDriveDeviceCollection.md)
 - [Nodeum::TapeLibrary](docs/TapeLibrary.md)
 - [Nodeum::TapeLibraryAllOf](docs/TapeLibraryAllOf.md)
 - [Nodeum::TapeLibraryCollection](docs/TapeLibraryCollection.md)
 - [Nodeum::TapeLibraryDevice](docs/TapeLibraryDevice.md)
 - [Nodeum::TapeLibraryDeviceCollection](docs/TapeLibraryDeviceCollection.md)
 - [Nodeum::TapeStat](docs/TapeStat.md)
 - [Nodeum::TapeStatCollection](docs/TapeStatCollection.md)
 - [Nodeum::Task](docs/Task.md)
 - [Nodeum::TaskByWorkflowBucket](docs/TaskByWorkflowBucket.md)
 - [Nodeum::TaskByWorkflowBucketAllOf](docs/TaskByWorkflowBucketAllOf.md)
 - [Nodeum::TaskByWorkflowBuckets](docs/TaskByWorkflowBuckets.md)
 - [Nodeum::TaskCallback](docs/TaskCallback.md)
 - [Nodeum::TaskCallbackCollection](docs/TaskCallbackCollection.md)
 - [Nodeum::TaskCollection](docs/TaskCollection.md)
 - [Nodeum::TaskDestinationCollection](docs/TaskDestinationCollection.md)
 - [Nodeum::TaskDestinationDown](docs/TaskDestinationDown.md)
 - [Nodeum::TaskDestinationUp](docs/TaskDestinationUp.md)
 - [Nodeum::TaskExecution](docs/TaskExecution.md)
 - [Nodeum::TaskExecutionCollection](docs/TaskExecutionCollection.md)
 - [Nodeum::TaskFacet](docs/TaskFacet.md)
 - [Nodeum::TaskFacetAllOf](docs/TaskFacetAllOf.md)
 - [Nodeum::TaskFacetBucket](docs/TaskFacetBucket.md)
 - [Nodeum::TaskFacetBuckets](docs/TaskFacetBuckets.md)
 - [Nodeum::TaskFacetMetadataBucket](docs/TaskFacetMetadataBucket.md)
 - [Nodeum::TaskFacetMetadataKeyBucket](docs/TaskFacetMetadataKeyBucket.md)
 - [Nodeum::TaskFacetMetadataKeyBucketAllOf](docs/TaskFacetMetadataKeyBucketAllOf.md)
 - [Nodeum::TaskFacetMetadataKeyBuckets](docs/TaskFacetMetadataKeyBuckets.md)
 - [Nodeum::TaskFacetMetadataValueBuckets](docs/TaskFacetMetadataValueBuckets.md)
 - [Nodeum::TaskMetadataDefinition](docs/TaskMetadataDefinition.md)
 - [Nodeum::TaskMetadataDefinitionAllOf](docs/TaskMetadataDefinitionAllOf.md)
 - [Nodeum::TaskMetadataDefinitionCollection](docs/TaskMetadataDefinitionCollection.md)
 - [Nodeum::TaskMetadatum](docs/TaskMetadatum.md)
 - [Nodeum::TaskMetadatumCollection](docs/TaskMetadatumCollection.md)
 - [Nodeum::TaskOption](docs/TaskOption.md)
 - [Nodeum::TaskOptionCollection](docs/TaskOptionCollection.md)
 - [Nodeum::TaskSchedule](docs/TaskSchedule.md)
 - [Nodeum::TaskScheduleCollection](docs/TaskScheduleCollection.md)
 - [Nodeum::TaskSourceCollection](docs/TaskSourceCollection.md)
 - [Nodeum::TaskSourceDown](docs/TaskSourceDown.md)
 - [Nodeum::TaskSourceUp](docs/TaskSourceUp.md)
 - [Nodeum::TooLong](docs/TooLong.md)
 - [Nodeum::TooLongAllOf](docs/TooLongAllOf.md)
 - [Nodeum::TooShort](docs/TooShort.md)
 - [Nodeum::TooShortAllOf](docs/TooShortAllOf.md)
 - [Nodeum::TypeToPrimaryFacets](docs/TypeToPrimaryFacets.md)
 - [Nodeum::TypeToSecondaryFacets](docs/TypeToSecondaryFacets.md)
 - [Nodeum::UserConfiguration](docs/UserConfiguration.md)
 - [Nodeum::UserConfigurationCollection](docs/UserConfigurationCollection.md)


## Documentation for Authorization


### BasicAuth

- **Type**: HTTP basic authentication

### BearerAuth


- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

